package com.intershop.support.promotion.condition.descriptor;

import java.util.HashMap;

import com.intershop.beehive.core.capi.naming.NamingMgr;
import com.intershop.component.foundation.capi.condition.Condition;
import com.intershop.component.marketing.capi.promotion.condition.descriptor.PromotionConditionDescriptor;
import com.intershop.support.promotion.condition.evaluator.RecurringOrderConditionEvaluator;

public class RecurringOrderCondition extends PromotionConditionDescriptor
{
    /**
     * ID of the condition descriptor.
     */
    public static final String ID = "RecurringOrderCondition";

    public RecurringOrderCondition()
    {
        super(ID, PromotionConditionDescriptor.CONDITION_TYPE.Order);
        evaluator = new RecurringOrderConditionEvaluator();
        NamingMgr.injectMembers(evaluator);
        configTemplate = "inc/condition/RecurringOrderCondition";
        configErrorTemplate = "inc/condition/RecurringOrderConditionError";
        displayTemplate = "inc/condition/DisplayRecurringOrderCondition";
        addConditionParameters();
    }
    
    /**
     * Adds the parameters for <code>RecurringOrderCondition</code> to the
     * descriptor.
     * 
     * <ol>
     * <li>Minimum Order Value : <code>Integer</code></li>
     * </ol>
     */
    private void addConditionParameters()
    {
        HashMap<String, HashMap<String, String>> paramProps0 = new HashMap<>();
        HashMap<String, String> paramValidProps = new HashMap<>();
        
        // for repetitions
        paramValidProps.put("min", "1");
        paramValidProps.put("max", String.valueOf(Integer.MAX_VALUE));
        paramProps0.put("GlobalValidators-intrange", paramValidProps);
        addParameter("MinOrderValue", "java.lang.Integer", paramProps0, null, null,
                        "condition.error.RecurringOrderCondition.MinOrderValue");
    }

    /**
     * Returns the specified minimum order value for the condition.
     * 
     * @param condition
     *            The condition
     * @return The specified minimum order value, if not set, returns
     *         <code>null</code>
     */
    public Integer getMinOrderValue(Condition condition)
    {
        if (condition.getConditionDescriptorID().equals(ID))
        {
            return condition.getInteger("MinOrderValue");
        }
        return null;
    }    
}