package com.intershop.support.promotion.condition.evaluator;

import java.math.BigDecimal;

import javax.inject.Inject;

import com.intershop.beehive.bts.capi.orderprocess.LineItemCtnr;
import com.intershop.beehive.bts.internal.orderprocess.basket.BasketPO;
import com.intershop.component.application.capi.ApplicationBO;
import com.intershop.component.application.capi.CurrentApplicationBOProvider;
import com.intershop.component.basket.capi.BasketBO;
import com.intershop.component.basket.capi.BasketBORepository;
import com.intershop.component.basket.capi.extension.BasketBORecurringExtension;
import com.intershop.component.foundation.capi.condition.Condition;
import com.intershop.component.marketing.capi.promotion.evaluation.PromotionEvaluationContext;
import com.intershop.component.marketing.capi.promotion.evaluation.PromotionEvaluationObjects;
import com.intershop.component.marketing.capi.promotion.evaluation.PromotionEvaluationResult;
import com.intershop.component.marketing.capi.promotion.evaluation.PromotionFilterConditionEvaluator;
import com.intershop.component.marketing.internal.promotion.condition.evaluator.AbstractPromotionFilterConditionEvaluator;
import com.intershop.support.promotion.condition.descriptor.RecurringOrderCondition;

@SuppressWarnings("deprecation")
public class RecurringOrderConditionEvaluator extends AbstractPromotionFilterConditionEvaluator implements PromotionFilterConditionEvaluator
{    
    @Inject
    private CurrentApplicationBOProvider currentApplicationBOProvider;

    private static final String BASKET = "Basket";
    
    @Override
    public PromotionEvaluationResult evaluate(Condition condition,
                    PromotionEvaluationObjects promotionEvaluationObjects, int iterationCount,
                    PromotionEvaluationContext context, String filterConditionID, boolean filterConditionMandatory,
                    boolean effectDiscountLevel)
    {
        switch (context.getType())  
        {
            case BASKET:
            return evaluateBasketCondition(condition, promotionEvaluationObjects, iterationCount, context, filterConditionID, filterConditionMandatory);
        }
        
        return null;
    }

    private PromotionEvaluationResult evaluateBasketCondition(Condition condition,
                    PromotionEvaluationObjects promotionEvaluationObjects, int iterationCount,
                    PromotionEvaluationContext context, String filterConditionID, boolean filterConditionMandatory)
    {
        PromotionEvaluationResult promotionEvaluationResult = new PromotionEvaluationResult();
        promotionEvaluationResult.setSuccessful(false);
        // add the basket for more see Concept - Promotion Custom Parameter Passing and Cookbook - Promotions - Add Custom Parameters for the Promotion Process 
        LineItemCtnr basket = promotionEvaluationObjects.getCustomPromotionParameter(BASKET);       
        ApplicationBO applicationBO = currentApplicationBOProvider.get();
        BasketBORepository basketBORepository = applicationBO.getRepository("BasketBORepository");
        
        RecurringOrderCondition orderValueCondition = ((RecurringOrderCondition)context.getConditionDescriptorRegistry().getDescriptor(condition.getConditionDescriptorID()));        
        
        if (orderValueCondition.getMinOrderValue(condition) == null || basket == null)
        {
            return promotionEvaluationResult;   
        }
       
        BasketBO basketBO = basketBORepository.getBasketBO(((BasketPO)basket).getUUID());
        
        basketBO.getGrandTotalGross();
        
        if (basketBO.getGrandTotalGross().getValue().compareTo(BigDecimal.valueOf(orderValueCondition.getMinOrderValue(condition))) == -1)
        {
            return promotionEvaluationResult;  
        }
        
        BasketBORecurringExtension basketBORecurringExtension = basketBO.getExtension(BasketBORecurringExtension.EXTENSION_ID);
        
        if (basketBORecurringExtension == null)
        {
            return promotionEvaluationResult;   
        }  
        else
        {
            if (basketBORecurringExtension.isRecurring())
            {
                promotionEvaluationResult.setSuccessful(true);
            }
        }
        return promotionEvaluationResult;
    }        
}
